django-oidc-rp
##############

**Django-oidc-rp** is a lightweight - server side OpenID Connect Relying Party (RP/Client)
implementation for Django. It allows to easily integrate an OpenID Connect provider as the
authentication source in a Django project.

.. contents:: Table of Contents
    :local:

Documentation
=============

Online browsable documentation is available at https://django-oidc-rp.readthedocs.io.

Head over to the documentation for all the details on how to add OpenID Connect authentication
support to your Django project

Main requirements
=================

Python 3.4+, Django 1.11+.

Authors
=======

impak Finance <tech@impakfinance.com>.

License
=======

MIT. See ``LICENSE`` for more details.
